@@ -98,11 +98,12 @@ func loadSystems(c *ctx.Ctx) []error {
 			errs = append(errs, err)
 		} else {
 			c.Logger.Debugf("loaded %s system", sysCfg.Type)
+
+			c.AddSystem(&sys)
+			c.Logger.Debugf("setting system ID to %d", c.NumSystems()-1)
+			sys.SetID(c.NumSystems() - 1)
 		}
 
-		c.AddSystem(&sys)
-		c.Logger.Debugf("setting system ID to %d", c.NumSystems()-1)
-		sys.SetID(c.NumSystems() - 1)
 	}
 
 	return errs
@@ -119,7 +120,13 @@ var rootCmd = &cobra.Command{
 		var err error
 
 		c := ctx.New(EMBEDFS, &CFG, LOG)
-		_ = loadSystems(&c) // TODO: Handle errs
+		errs := loadSystems(&c)
+		if len(errs) > 0 {
+			for _, err = range errs {
+				c.Logger.Error(err)
+			}
+			panic("Error(s) loading system(s)")
+		}
 
 		tui := tea.NewProgram(ui.NewModel(&c), tea.WithAltScreen())
 		err = tui.Start()
