@@ -3,7 +3,6 @@ package discourse
 import (
 	"context"
 	"fmt"
-	"net/http"
 	"net/url"
 	"strconv"
 	"time"
@@ -20,10 +19,11 @@ import (
 )
 
 type System struct {
-	ID     int
-	config map[string]interface{}
-	logger *zap.SugaredLogger
-	client *api.Client
+	ID        int
+	config    map[string]interface{}
+	logger    *zap.SugaredLogger
+	client    *api.Client
+	clientCfg api.ClientConfig
 }
 
 func (sys *System) GetID() int {
@@ -113,12 +113,13 @@ func (sys *System) Load() error {
 		credentials[k] = v.(string)
 	}
 
-	sys.client = api.NewClient(&api.ClientConfig{
-		Endpoint:    url.(string),
-		Credentials: credentials,
-		HTTPClient:  http.DefaultClient,
-		Logger:      sys.logger,
-	})
+	sys.clientCfg = api.NewDefaultClientConfig(
+		url.(string),
+		sys.config["proxy"].(string),
+		credentials,
+		sys.logger,
+	)
+	sys.client = api.NewClient(&sys.clientCfg)
 
 	return nil
 }
@@ -131,20 +132,38 @@ func (sys *System) ListForums() ([]forum.Forum, error) {
 		return []forum.Forum{}, err
 	}
 
-	for _, cat := range cats.CategoryList.Categories {
-		models = append(models, forum.Forum{
-			ID:   strconv.Itoa(cat.ID),
-			Name: cat.Name,
-
-			Info: cat.Description,
-
-			SysIDX: sys.ID,
-		})
-	}
+	models = sys.recurseForums(&cats.CategoryList.Categories, nil)
 
 	return models, nil
 }
 
+func (sys *System) recurseForums(cats *[]api.CategoryModel, parent *forum.Forum) []forum.Forum {
+	var models []forum.Forum
+
+	sys.logger.Debugf("recursing categories: %d\n", len(*cats))
+	for i := 0; i < len(*cats); i++ {
+		sys.logger.Debugf("adding category: %s\n", (*cats)[i].Name)
+
+		var name = (*cats)[i].Name
+		if parent != nil {
+			name = fmt.Sprintf("%s / %s", parent.Name, name)
+		}
+		f := forum.Forum{
+			ID:   strconv.Itoa((*cats)[i].ID),
+			Name: name,
+
+			Info: (*cats)[i].Description,
+
+			SysIDX: sys.ID,
+		}
+		models = append(models, f)
+
+		models = append(models, sys.recurseForums(&(*cats)[i].SubcategoryList, &f)...)
+	}
+
+	return models
+}
+
 func (sys *System) ListPosts(forumID string) ([]post.Post, error) {
 	var catSlug string = ""
 	var catID int = -1
